@@ -5,7 +5,7 @@ use Moose::Util::TypeConstraints;
 use Captcha::noCAPTCHA;
 use namespace::autoclean;
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 extends 'HTML::FormHandler::Field';
 
@@ -16,6 +16,7 @@ has '+required' => ( default => 1 );
 
 has [qw/site_key secret_key/] => (is=>'rw', isa=>'Str', required => 1,lazy_build => 1);
 has 'theme' => (is=>'ro',isa=> enum([qw(dark light)]),default => 'light');
+has 'noscript' => (is=>'ro',isa=> 'Bool',default => 0);
 has 'remote_address' => (is=>'ro', isa=>'Str', required => 1, lazy_build => 1);
 has 'api_url' => (is=>'ro', isa=>'Str', required => 1, lazy_build => 1);
 has 'api_timeout' => (is=>'ro', isa=>'Int', required => 1, lazy_build => 1);
@@ -68,6 +69,7 @@ sub _build__nocaptcha {
 		site_key    => $self->site_key,
 		secret_key  => $self->secret_key,
 		theme       => $self->theme,
+		noscript    => $self->noscript,
 	});
 }
 
@@ -142,6 +144,10 @@ Required. The secret key you get when you create an account on L<https://www.goo
 
 Optional. The color theme of the widget. Options are 'light ' or 'dark' (Default: light)
 
+=head2 noscript
+
+Optional. When true, includes the <noscript> markup in the rendered html. (Default: false)
+
 =head2 remote_address
 
 Optional. The user's IP address. Google states this is optional.  If you are using
@@ -176,6 +182,7 @@ Default is HTML::FormHandlerX::Field::noCAPTCHA
 The following modules or resources may be of interest.
 
 L<HTML::FormHandler>
+L<Captcha::noCAPTCHA>
 
 See it in action at L<https://www.httpuptime.com>
 
